package router

import (
	"github.com/gin-gonic/gin"
	jwt "github.com/go-admin-team/go-admin-core/sdk/pkg/jwtauth"
	"go-admin/app/admin/apis/migumanage"
)

// registerMiGuControlManageRouter 需认证的路由代码
func registerMiGuControlManageRouter(v1 *gin.RouterGroup, authMiddleware *jwt.GinJWTMiddleware) {
	apiMiGu := migumanage.MiGuDeployService{}
	api := v1.Group("/admin")
	{
		api.POST("product/list", apiMiGu.ProductList) // 查询权益产品
		api.POST("product/add", apiMiGu.AddProduct)   // 新增产品
		//api.POST("product/update", apiMiGu.UpdateProduct) // 编辑产品
		//api.POST("product/delete", apiMiGu.DeleteProduct) // 删除产品

		api.POST("channel/list", apiMiGu.ChannelList) // 查询渠道列表
		api.POST("channel/add", apiMiGu.AddChannel)   // 新增渠道
		//api.POST("channel/update", apiMiGu.UpdateChannel) // 编辑渠道
		//api.POST("channel/delete", apiMiGu.DeleteChannel) // 删除渠道

		api.POST("transaction/list", apiMiGu.TransactionList)              // 查询交易流水记录
		api.POST("order/list", apiMiGu.OrderList)                          // 查询订单列表
		api.POST("historical_summary/list", apiMiGu.HistoricalSummaryList) // 历史汇总查询
		api.POST("realtime_summary/list", apiMiGu.RealtimeSummaryList)     // 当日实时汇总
		api.POST("user_retention/list", apiMiGu.UserRetentionList)         // 用户留存记录
		api.POST("sys_channel/list", apiMiGu.SysChannelList)               // 查询系统所有渠道编码
		api.POST("home/data", apiMiGu.HomepageDataSummary)                 // 查询首页汇总数据
	}
}

// registerMiGuControlManageUnAuthRouter 无需认证的路由代码
func registerMiGuControlManageUnAuthRouter(v1 *gin.RouterGroup) {
	apiMiGu := migumanage.MiGuDeployService{}
	api := v1.Group("/notice")
	{
		api.GET("subscribe", apiMiGu.SubscribeNotice)     // 订购成功通知
		api.GET("unsubscribe", apiMiGu.UnsubscribeNotice) // 退订通知
	}

	apiPost := v1.Group("/migu")
	{
		apiPost.POST("send_captcha", apiMiGu.SendCaptcha)                // 下单接口(下发验证码)
		apiPost.POST("submit_order", apiMiGu.SubmitOrder)                // 提交接口(提交验证码)
		apiPost.POST("order/check", apiMiGu.CheckOrder)                  // 查询是否已经退订接口
		apiPost.POST("order/check_rights_info", apiMiGu.CheckRightsInfo) // 查询是否已经退订接口（咪咕）
	}

	apiEx := v1.Group("/coupon_provider")
	{
		apiEx.POST("send_captcha", apiMiGu.SendCaptchaEx)                // 下单接口(下发验证码)-对外
		apiEx.POST("submit_order", apiMiGu.SubmitOrderEx)                // 提交接口(提交验证码)-对外
		apiEx.POST("order/check", apiMiGu.CheckOrderEx)                  // 查询是否已经退订接口-对外
		apiEx.POST("order/check_rights_info", apiMiGu.CheckRightsInfoEx) // 查询是否已经退订接口（咪咕）-对外
	}
}
